@@ -1,6 +1,6 @@
 /*  
  *  Global Time - Set of clocks showing time in different parts of world.
- *  Copyright 2006 Juha Kautto (kautto.juha@kolumbus.fi)
+ *  Copyright 2006-2011 Juha Kautto (kautto.juha@kolumbus.fi)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -45,8 +45,8 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <libxfce4util/libxfce4util.h>
 #include "globaltime.h"
+#include "../src/orage-i18n.h"
 
 
 #define NAME_VERSION "Global Time (2.1)"
@@ -106,7 +106,7 @@ static gboolean global_time_active_already(GdkAtom *atom)
         return(FALSE); 
 }
 
-static void show_globaltime()
+static void raise_window(void)
 {
     GdkWindow *window;
 
@@ -116,6 +116,7 @@ static void show_globaltime()
     window = GTK_WIDGET(clocks.window)->window;
     gdk_x11_window_set_user_time(window, gdk_x11_get_server_time(window));
     gtk_widget_show(clocks.window);
+    gtk_window_present(GTK_WINDOW(clocks.window));
 }
 
 static gboolean client_message_received(GtkWidget *widget
@@ -123,9 +124,7 @@ static gboolean client_message_received(GtkWidget *widget
 {
     if (event->message_type == 
             gdk_atom_intern("_XFCE_GLOBALTIME_RAISE", FALSE)) {
-        /* we need to hide it first since minimized windows are visible ! */
-        gtk_widget_hide(clocks.window); 
-        show_globaltime();
+        raise_window();
         return(TRUE);
     }
     else if (event->message_type ==
@@ -134,7 +133,7 @@ static gboolean client_message_received(GtkWidget *widget
             gtk_widget_hide(clocks.window);
             return(TRUE);
         }
-        show_globaltime();
+        raise_window();
         return(TRUE);
     }
                                                                                 
@@ -391,7 +390,7 @@ static void add_default_clock(void)
     write_file();
 }
 
-void upd_clock(clock_struct *clockp)
+static void upd_clock(clock_struct *clockp)
 {
     struct tm *now;
 
@@ -436,12 +435,12 @@ static gboolean upd_clocks(void)
     return(TRUE);
 }
 
-void adj_hh_changed(GtkSpinButton *cb, gpointer user_data)
+static void adj_hh_changed(GtkSpinButton *cb, gpointer user_data)
 {
     clocks.hh_adj = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(cb));
 }
 
-void adj_mm_changed(GtkSpinButton *cb, gpointer user_data)
+static void adj_mm_changed(GtkSpinButton *cb, gpointer user_data)
 {
     clocks.mm_adj = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(cb));
 }
@@ -476,7 +475,7 @@ static void init_hdr_button(void)
             , clocks.hdr_adj_hh, FALSE, FALSE, 0);
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(clocks.hdr_adj_hh), (gdouble)0);
     gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(clocks.hdr_adj_hh), TRUE);
-    gtk_widget_set_size_request(clocks.hdr_adj_hh, 40, -1);
+    gtk_widget_set_size_request(clocks.hdr_adj_hh, 45, -1);
     gtk_tooltips_set_tip(clocks.tips, clocks.hdr_adj_hh
             , _("adjust to change hour"), NULL);
     g_signal_connect((gpointer) clocks.hdr_adj_hh, "changed"
@@ -492,7 +491,7 @@ static void init_hdr_button(void)
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(clocks.hdr_adj_mm), (gdouble)0);
     gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(clocks.hdr_adj_mm), TRUE);
     gtk_spin_button_set_increments(GTK_SPIN_BUTTON(clocks.hdr_adj_mm), 30, 1);
-    gtk_widget_set_size_request(clocks.hdr_adj_mm, 40, -1);
+    gtk_widget_set_size_request(clocks.hdr_adj_mm, 45, -1);
     gtk_tooltips_set_tip(clocks.tips, clocks.hdr_adj_mm
             , _("adjust to change minute. Click arrows with button 2 to change only 1 minute."), NULL);
     g_signal_connect((gpointer) clocks.hdr_adj_mm, "changed"
@@ -509,7 +508,7 @@ static gboolean clean_up(GtkObject *obj, GdkEvent *event, gint g)
     return(FALSE);
 }
 
-static void initialize_clocks()
+static void initialize_clocks(void)
 {
     GtkWidget *button;
 
@@ -615,7 +614,13 @@ static void create_global_time(void)
 
 int main(int argc, char *argv[])
 {
-    xfce_textdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
+    /* init i18n = nls to use gettext */
+    bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+#endif
+    textdomain(GETTEXT_PACKAGE);
+
     gtk_init(&argc, &argv);
     create_global_time();
     gtk_main();
