@@ -1,7 +1,7 @@
 /* vim: set expandtab ts=4 sw=4: */
 /*
  *
- *  Copyright © 2006-2007 Juha Kautto <juha@xfce.org>
+ *  Copyright © 2006-2011 Juha Kautto <juha@xfce.org>
  *
  *  it under the terms of the GNU Library General Public License as published 
  *  by the Free Software Foundation; either version 2 of the License, or
@@ -33,11 +33,12 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkevents.h>
+#include <gdk/gdkx.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4panel/libxfce4panel.h>
 
+#include "../src/functions.h"
 #include "xfce4-orageclock-plugin.h"
 
 /* -------------------------------------------------------------------- *
@@ -357,7 +358,7 @@ static gboolean popup_program(GtkWidget *widget, gchar *program, Clock *clock
             g_unsetenv("TZ");
         tzset();
 
-        if (!xfce_exec(program, FALSE, FALSE, &error)) 
+        if (!orage_exec(program, FALSE, &error)) 
             g_message("%s: start of %s failed", OC_NAME, program);
 
         if ((clock->timezone->str != NULL) && (clock->timezone->len > 0)) {
