@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2005-2008 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2005-2011 Juha Kautto  (juha at xfce.org)
  * Copyright (c) 2003-2005 Mickael Graf (korbinus at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -51,14 +51,20 @@
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
 #include <glib/gstdio.h>
+#ifdef HAVE_LIBICAL
+#include <libical/ical.h>
+#include <libical/icalss.h>
+#else
 #include <ical.h>
 #include <icalss.h>
+#endif
 
 #include "orage-i18n.h"
 #include "functions.h"
 #include "mainbox.h"
 #include "reminder.h"
 #include "ical-code.h"
+#include "ical-internal.h"
 #include "event-list.h"
 #include "appointment.h"
 #include "parameters.h"
@@ -71,25 +77,6 @@
 
 
 
-/* this is in ical-code.c, too. ugly. should be in h file */
-typedef struct
-{
-    struct icaltimetype stime; /* start time */
-    struct icaltimetype etime; /* end time */
-    struct icaldurationtype duration;
-    struct icaltimetype ctime; /* completed time for VTODO appointmnets */
-    icalcomponent_kind ikind;  /* type of component, VEVENt, VTODO... */
-} xfical_period;
-
-/* in ical-code.c: */
-char *ic_get_char_timezone(icalproperty *p);
-struct icaltimetype ic_convert_to_timezone(struct icaltimetype t
-        , icalproperty *p);
-xfical_period ic_get_period(icalcomponent *c, gboolean local);
-gboolean ic_internal_file_open(icalcomponent **p_ical
-        , icalset **p_fical, gchar *file_icalpath, gboolean test);
-
-
 extern icalset *ic_fical;
 extern icalcomponent *ic_ical;
 #ifdef HAVE_ARCHIVE
