@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2006-2008 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2006-2011 Juha Kautto  (juha at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,8 +41,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 
-#include <libxfcegui4/libxfcegui4.h>
-
+#include "orage-i18n.h"
 #include "functions.h"
 #include "tray_icon.h"
 #include "ical-code.h"
@@ -50,6 +49,7 @@
 #include "parameters.h"
 #include "mainbox.h"
 
+extern int g_log_level;
 
 static gboolean is_running = FALSE;
 
@@ -110,8 +110,11 @@ typedef struct _Itf
     GtkWidget *extra_tab_label;
     GtkWidget *extra_vbox;
     /* select_always_today */
-    GtkWidget *always_today_frame;
-    GtkWidget *always_today_checkbutton;
+    GtkWidget *select_day_frame;
+    /* GtkWidget *always_today_checkbutton; */
+    GSList    *select_day_radiobutton_group;
+    GtkWidget *select_day_today_radiobutton;
+    GtkWidget *select_day_old_radiobutton;
     /* icon size */
     GtkWidget *icon_size_frame;
     GtkWidget *use_dynamic_icon_checkbutton;
@@ -132,7 +135,7 @@ typedef struct _Itf
 /* Return the first day of the week, where 0=monday, 6=sunday.
  *     Borrowed from GTK+:s Calendar Widget, but modified
  *     to return 0..6 mon..sun, which is what libical uses */
-int get_first_weekday_from_locale()
+static int get_first_weekday_from_locale(void)
 {
 #ifdef HAVE__NL_TIME_FIRST_WEEKDAY
     union { unsigned int word; char *string; } langinfo;
@@ -164,16 +167,19 @@ static void dialog_response(GtkWidget *dialog, gint response_id
 {
     Itf *itf = (Itf *)user_data;
     gchar *helpdoc;
+    GError *error = NULL;
 
     if (response_id == GTK_RESPONSE_HELP) {
         /* Needs to be in " to keep # */
-        helpdoc = g_strconcat("xfbrowser4 \"", PACKAGE_DATA_DIR
+        helpdoc = g_strconcat("firefox \"", PACKAGE_DATA_DIR
                 , G_DIR_SEPARATOR_S, "orage"
                 , G_DIR_SEPARATOR_S, "doc"
                 , G_DIR_SEPARATOR_S, "C"
                 , G_DIR_SEPARATOR_S, "orage.html#orage-preferences-window\""
                 , NULL);
-        orage_exec(helpdoc, NULL, NULL);
+        if (!orage_exec(helpdoc, FALSE, &error))
+            orage_message(100, "start of %s failed: %s", helpdoc
+                    , error->message);
     }
     else { /* delete signal or close response */
         write_parameters();
@@ -194,7 +200,7 @@ static void sound_application_changed(GtkWidget *dialog, gpointer user_data)
             GTK_ENTRY(itf->sound_application_entry)));
 }
 
-static void set_border()
+static void set_border(void)
 {
     gtk_window_set_decorated(GTK_WINDOW(((CalWin *)g_par.xfcal)->mWindow)
             , g_par.show_borders);
@@ -209,7 +215,7 @@ static void borders_changed(GtkWidget *dialog, gpointer user_data)
     set_border();
 }
 
-static void set_menu()
+static void set_menu(void)
 {
     if (g_par.show_menu)
         gtk_widget_show(((CalWin *)g_par.xfcal)->mMenubar);
@@ -226,7 +232,7 @@ static void menu_changed(GtkWidget *dialog, gpointer user_data)
     set_menu();
 }
 
-static void set_calendar()
+static void set_calendar(void)
 {
     gtk_calendar_set_display_options(
             GTK_CALENDAR(((CalWin *)g_par.xfcal)->mCalendar)
@@ -262,7 +268,7 @@ static void weeks_changed(GtkWidget *dialog, gpointer user_data)
     set_calendar();
 }
 
-static void set_todos()
+static void set_todos(void)
 {
     if (g_par.show_todos)
         gtk_widget_show_all(((CalWin *)g_par.xfcal)->mTodo_vbox);
@@ -288,7 +294,7 @@ static void show_events_spin_changed(GtkSpinButton *sb, gpointer user_data)
         gtk_widget_hide_all(((CalWin *)g_par.xfcal)->mEvent_vbox);
 }
 
-static void set_stick()
+static void set_stick(void)
 {
     if (g_par.set_stick)
         gtk_window_stick(GTK_WINDOW(((CalWin *)g_par.xfcal)->mWindow));
@@ -305,7 +311,7 @@ static void stick_changed(GtkWidget *dialog, gpointer user_data)
     set_stick();
 }
 
-static void set_ontop()
+static void set_ontop(void)
 {
     gtk_window_set_keep_above(GTK_WINDOW(((CalWin *)g_par.xfcal)->mWindow)
             , g_par.set_ontop);
@@ -320,7 +326,7 @@ static void ontop_changed(GtkWidget *dialog, gpointer user_data)
     set_ontop();
 }
 
-static void set_taskbar()
+static void set_taskbar(void)
 {
     gtk_window_set_skip_taskbar_hint(
             GTK_WINDOW(((CalWin *)g_par.xfcal)->mWindow), !g_par.show_taskbar);
@@ -335,7 +341,7 @@ static void taskbar_changed(GtkWidget *dialog, gpointer user_data)
     set_taskbar();
 }
 
-static void set_pager()
+static void set_pager(void)
 {
     gtk_window_set_skip_pager_hint(GTK_WINDOW(((CalWin *)g_par.xfcal)->mWindow)
             , !g_par.show_pager);
@@ -350,7 +356,7 @@ static void pager_changed(GtkWidget *dialog, gpointer user_data)
     set_pager();
 }
 
-static void set_systray()
+static void set_systray(void)
 {
     GdkPixbuf *orage_logo;
 
@@ -449,12 +455,12 @@ static void archive_threshold_spin_changed(GtkSpinButton *sb
 }
 #endif
 
-static void always_today_changed(GtkWidget *dialog, gpointer user_data)
+static void select_day_changed(GtkWidget *dialog, gpointer user_data)
 {
     Itf *itf = (Itf *)user_data;
 
     g_par.select_always_today = gtk_toggle_button_get_active(
-            GTK_TOGGLE_BUTTON(itf->always_today_checkbutton));
+            GTK_TOGGLE_BUTTON(itf->select_day_today_radiobutton));
 }
 
 static void use_dynamic_icon_changed(GtkWidget *dialog, gpointer user_data)
@@ -480,9 +486,10 @@ static void create_parameter_dialog_main_setup_tab(Itf *dialog)
     GtkWidget *hbox, *vbox, *label;
 
     dialog->setup_vbox = gtk_vbox_new(FALSE, 0);
+    /* FIXME: this could be something simpler than framebox */
     dialog->setup_tab = 
             orage_create_framebox_with_content(NULL, dialog->setup_vbox);
-    dialog->setup_tab_label = gtk_label_new(_("Main setups"));
+    dialog->setup_tab_label = gtk_label_new(_("Main settings"));
     gtk_notebook_append_page(GTK_NOTEBOOK(dialog->notebook)
           , dialog->setup_tab, dialog->setup_tab_label);
 
@@ -566,9 +573,10 @@ static void create_parameter_dialog_display_tab(Itf *dialog)
     GtkWidget *hbox, *vbox, *label;
 
     dialog->display_vbox = gtk_vbox_new(FALSE, 0);
+    /* FIXME: this could be something simpler than framebox */
     dialog->display_tab = 
         orage_create_framebox_with_content(NULL, dialog->display_vbox);
-    dialog->display_tab_label = gtk_label_new(_("Display"));
+    dialog->display_tab_label = gtk_label_new(_("Display settings"));
     gtk_notebook_append_page(GTK_NOTEBOOK(dialog->notebook)
           , dialog->display_tab, dialog->display_tab_label);
 
@@ -639,14 +647,14 @@ static void create_parameter_dialog_display_tab(Itf *dialog)
     */
 
     dialog->set_stick_checkbutton = gtk_check_button_new_with_mnemonic(
-            _("Set sticked"));
+            _("Show on all desktops"));
     gtk_box_pack_start(GTK_BOX(vbox)
             , dialog->set_stick_checkbutton, FALSE, FALSE, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
             dialog->set_stick_checkbutton), g_par.set_stick);
 
     dialog->set_ontop_checkbutton = gtk_check_button_new_with_mnemonic(
-            _("Set on top"));
+            _("Keep on top"));
     gtk_box_pack_start(GTK_BOX(vbox)
             , dialog->set_ontop_checkbutton, FALSE, FALSE, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
@@ -753,19 +761,22 @@ static void create_parameter_dialog_extra_setup_tab(Itf *dialog)
     GtkWidget *hbox, *vbox, *label;
 
     dialog->extra_vbox = gtk_vbox_new(FALSE, 0);
+    /* FIXME: this could be something simpler than framebox */
     dialog->extra_tab = 
             orage_create_framebox_with_content(NULL, dialog->extra_vbox);
-    dialog->extra_tab_label = gtk_label_new(_("Extra setups"));
+    dialog->extra_tab_label = gtk_label_new(_("Extra settings"));
     gtk_notebook_append_page(GTK_NOTEBOOK(dialog->notebook)
           , dialog->extra_tab, dialog->extra_tab_label);
 
-    /****** select_always_today ******/
-    hbox = gtk_hbox_new(FALSE, 0);
-    dialog->always_today_frame = orage_create_framebox_with_content(
-            _("Select always today"), hbox);
+    /****** On Calendar Window Open ******/
+    dialog->select_day_radiobutton_group = NULL;
+    vbox = gtk_vbox_new(FALSE, 0);
+    dialog->select_day_frame = orage_create_framebox_with_content(
+            _("On Calendar Window Open"), vbox);
     gtk_box_pack_start(GTK_BOX(dialog->extra_vbox)
-            , dialog->always_today_frame, FALSE, FALSE, 5);
+            , dialog->select_day_frame, FALSE, FALSE, 5);
 
+    /*
     dialog->always_today_checkbutton = 
             gtk_check_button_new_with_mnemonic(_("Select always today"));
     gtk_box_pack_start(GTK_BOX(hbox)
@@ -777,6 +788,35 @@ static void create_parameter_dialog_extra_setup_tab(Itf *dialog)
             , NULL);
     g_signal_connect(G_OBJECT(dialog->always_today_checkbutton), "toggled"
             , G_CALLBACK(always_today_changed), dialog);
+            */
+
+    dialog->select_day_today_radiobutton =
+            gtk_radio_button_new_with_mnemonic(NULL, _("Select Today's Date"));
+    gtk_box_pack_start(GTK_BOX(vbox)
+            , dialog->select_day_today_radiobutton, FALSE, FALSE, 0);
+    gtk_radio_button_set_group(
+            GTK_RADIO_BUTTON(dialog->select_day_today_radiobutton)
+            , dialog->select_day_radiobutton_group);
+    dialog->select_day_radiobutton_group = gtk_radio_button_get_group(
+            GTK_RADIO_BUTTON(dialog->select_day_today_radiobutton));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
+            dialog->select_day_today_radiobutton), g_par.select_always_today);
+
+    dialog->select_day_old_radiobutton =
+            gtk_radio_button_new_with_mnemonic(NULL
+                    , _("Select Previously Selected Date"));
+    gtk_box_pack_start(GTK_BOX(vbox)
+            , dialog->select_day_old_radiobutton, FALSE, FALSE, 0);
+    gtk_radio_button_set_group(
+            GTK_RADIO_BUTTON(dialog->select_day_old_radiobutton)
+            , dialog->select_day_radiobutton_group);
+    dialog->select_day_radiobutton_group = gtk_radio_button_get_group(
+            GTK_RADIO_BUTTON(dialog->select_day_old_radiobutton));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
+            dialog->select_day_old_radiobutton), !g_par.select_always_today);
+
+    g_signal_connect(G_OBJECT(dialog->select_day_today_radiobutton), "toggled"
+            , G_CALLBACK(select_day_changed), dialog);
 
     /***** use dynamic tray icon *****/
     hbox = gtk_vbox_new(FALSE, 0);
@@ -857,7 +897,7 @@ static void create_parameter_dialog_extra_setup_tab(Itf *dialog)
             , G_CALLBACK(el_extra_days_spin_changed), dialog);
 }
 
-Itf *create_parameter_dialog()
+static Itf *create_parameter_dialog(void)
 {
     Itf *dialog;
     GdkPixbuf *orage_logo;
@@ -865,7 +905,7 @@ Itf *create_parameter_dialog()
     dialog = g_new(Itf, 1);
     dialog->Tooltips = gtk_tooltips_new();
 
-    dialog->orage_dialog = xfce_titled_dialog_new();
+    dialog->orage_dialog = gtk_dialog_new();
     gtk_window_set_default_size(GTK_WINDOW(dialog->orage_dialog), 300, 350);
     gtk_window_set_title(GTK_WINDOW(dialog->orage_dialog)
             , _("Orage Preferences"));
@@ -913,21 +953,21 @@ Itf *create_parameter_dialog()
     return(dialog);
 }
 
-OrageRc *orage_parameters_file_open(gboolean read_only)
+static OrageRc *orage_parameters_file_open(gboolean read_only)
 {
     gchar *fpath;
     OrageRc *orc;
 
-    fpath = orage_config_file_location(ORAGE_PAR_FILE);
-    if ((orc = (OrageRc *)orage_rc_file_open(fpath, read_only)) == NULL) {
-        orage_message(150, "orage_category_file_open: Parameter file open failed.");
+    fpath = orage_config_file_location(ORAGE_PAR_DIR_FILE);
+    if ((orc = orage_rc_file_open(fpath, read_only)) == NULL) {
+        orage_message(150, "orage_parameters_file_open: Parameter file open failed.(%s)", fpath);
     }
     g_free(fpath);
 
     return(orc);
 }
 
-void write_parameters()
+void write_parameters(void)
 {
     OrageRc *orc;
     gint i;
@@ -935,6 +975,7 @@ void write_parameters()
 
     orc = orage_parameters_file_open(FALSE);
 
+    orage_rc_set_group(orc, "PARAMETERS");
     orage_rc_put_str(orc, "Timezone", g_par.local_timezone);
 #ifdef HAVE_ARCHIVE
     orage_rc_put_int(orc, "Archive limit", g_par.archive_limit);
@@ -993,7 +1034,7 @@ void write_parameters()
         g_sprintf(f_par, "Foreign file %02d read-only", i);
         orage_rc_del_item(orc, f_par);
     }
-    orage_rc_put_int(orc, "Logging level", g_par.log_level);
+    orage_rc_put_int(orc, "Logging level", g_log_level);
     orage_rc_put_int(orc, "Priority list limit", g_par.priority_list_limit);
 
     orage_rc_file_close(orc);
@@ -1002,7 +1043,7 @@ void write_parameters()
 /* let's try to find the timezone name by comparing this file to
  * timezone files from the default location. This does not work
  * always, but is the best trial we can do */
-void init_dtz_check_dir(gchar *tz_dirname, gchar *tz_local, gint len)
+static void init_dtz_check_dir(gchar *tz_dirname, gchar *tz_local, gint len)
 {
     gint tz_offset = strlen("/usr/share/zoneinfo/");
     gsize tz_len;         /* file lengths */
@@ -1023,7 +1064,7 @@ void init_dtz_check_dir(gchar *tz_dirname, gchar *tz_local, gint len)
             }
             else if (g_file_get_contents(tz_fullfile, &tz_data, &tz_len
                     , &error)) {
-                if (len == tz_len && !memcmp(tz_local, tz_data, len)) {
+                if (len == (int)tz_len && !memcmp(tz_local, tz_data, len)) {
                     /* this is a match (length is tested first since that 
                      * test is quick and it eliminates most) */
                     g_par.local_timezone = g_strdup(tz_fullfile+tz_offset);
@@ -1048,7 +1089,7 @@ void init_dtz_check_dir(gchar *tz_dirname, gchar *tz_local, gint len)
     }
 }
 
-void init_default_timezone()
+static void init_default_timezone(void)
 {
     gsize len;            /* file lengths */
     gchar *tz_local;      /* local timezone data */
@@ -1090,17 +1131,18 @@ void read_parameters(void)
 
     orc = orage_parameters_file_open(TRUE);
 
+    orage_rc_set_group(orc, "PARAMETERS");
     g_par.local_timezone = orage_rc_get_str(orc, "Timezone", "not found");
     if (!strcmp(g_par.local_timezone, "not found")) { 
         init_default_timezone();
     }
 #ifdef HAVE_ARCHIVE
     g_par.archive_limit = orage_rc_get_int(orc, "Archive limit", 0);
-    fpath = orage_data_file_location(ORAGE_ARC_FILE);
+    fpath = orage_data_file_location(ORAGE_ARC_DIR_FILE);
     g_par.archive_file = orage_rc_get_str(orc, "Archive file", fpath);
     g_free(fpath);
 #endif
-    fpath = orage_data_file_location(ORAGE_APP_FILE);
+    fpath = orage_data_file_location(ORAGE_APP_DIR_FILE);
     g_par.orage_file = orage_rc_get_str(orc, "Orage file", fpath);
     g_free(fpath);
     g_par.sound_application=orage_rc_get_str(orc, "Sound application", "play");
@@ -1141,13 +1183,13 @@ void read_parameters(void)
         g_sprintf(f_par, "Foreign file %02d read-only", i);
         g_par.foreign_data[i].read_only = orage_rc_get_bool(orc, f_par, TRUE);
     }
-    g_par.log_level = orage_rc_get_int(orc, "Logging level", 0);
+    g_log_level = orage_rc_get_int(orc, "Logging level", 0);
     g_par.priority_list_limit = orage_rc_get_int(orc, "Priority list limit", 8);
 
     orage_rc_file_close(orc);
 }
 
-void show_parameters()
+void show_parameters(void)
 {
     static Itf *dialog = NULL;
 
@@ -1160,7 +1202,7 @@ void show_parameters()
     }
 }
 
-void set_parameters()
+void set_parameters(void)
 {
     set_menu();
     set_border();
