@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2006-2008 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2006-2011 Juha Kautto  (juha at xfce.org)
  * Copyright (c) 2004-2006 Mickael Graf (korbinus at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,8 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
+#include <gdk/gdkevents.h>
+#include <gdk/gdkx.h>
 
 #include "orage-i18n.h"
 #include "functions.h"
@@ -42,13 +44,12 @@
 #include "event-list.h"
 #include "appointment.h"
 #include "parameters.h"
+#include "tray_icon.h"
 
 #define ORAGE_TRAYICON ((GtkStatusIcon *)g_par.trayIcon)
 
-void orage_toggle_visible();
 
-
-void on_Today_activate(GtkMenuItem *menuitem, gpointer user_data)
+static void on_Today_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
     struct tm *t;
     CalWin *xfcal = (CalWin *)user_data;
@@ -60,12 +61,12 @@ void on_Today_activate(GtkMenuItem *menuitem, gpointer user_data)
     el = create_el_win(NULL);
 }
 
-void on_preferences_activate(GtkMenuItem *menuitem, gpointer user_data)
+static void on_preferences_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
     show_parameters();
 }
 
-void on_new_appointment_activate(GtkMenuItem *menuitem, gpointer user_data)
+static void on_new_appointment_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
     struct tm *t;
     char cur_date[9];
@@ -76,24 +77,70 @@ void on_new_appointment_activate(GtkMenuItem *menuitem, gpointer user_data)
     create_appt_win("NEW", cur_date);  
 }
 
-void on_about_activate(GtkMenuItem *menuitem, gpointer user_data)
+static void on_about_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
     create_wAbout((GtkWidget *)menuitem, user_data);
 }
 
-void toggle_visible_cb(GtkStatusIcon *status_icon, gpointer user_data)
+static void on_globaltime_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
-    orage_toggle_visible ();
+    GError *error = NULL;
+
+    if (!orage_exec("globaltime", FALSE, &error))
+        g_message("%s: start of %s failed: %s", "Orage", "globaltime"
+                , error->message);
 }
 
-void show_menu(GtkStatusIcon *status_icon, guint button, guint activate_time
+static gboolean button_press_cb(GtkStatusIcon *status_icon, GdkEventButton *event
+        , gpointer user_data)
+{
+    GdkAtom atom;
+    GdkEventClient gev;
+    Window xwindow;
+
+    if (event->type != GDK_BUTTON_PRESS) /* double or triple click */
+        return(FALSE); /* ignore */
+    else if (event->button == 2) {
+        /* send message to program to check if it is running */
+        atom = gdk_atom_intern("_XFCE_GLOBALTIME_RUNNING", FALSE);
+        if ((xwindow = XGetSelectionOwner(GDK_DISPLAY(),
+                gdk_x11_atom_to_xatom(atom))) != None) { /* yes, then toggle */
+            gev.type = GDK_CLIENT_EVENT;
+            gev.window = NULL;
+            gev.send_event = TRUE;
+            gev.message_type = gdk_atom_intern("_XFCE_GLOBALTIME_TOGGLE_HERE"
+                    , FALSE);
+            gev.data_format = 8;
+
+            if (!gdk_event_send_client_message((GdkEvent *) &gev,
+                    (GdkNativeWindow)xwindow))
+                 g_message("%s: send message to %s failed", "Orage"
+                         , "globaltime");
+
+            return(TRUE);
+        }
+        else { /* not running, let's try to start it. Need to reset TZ! */
+            on_globaltime_activate(NULL, NULL);
+            return(TRUE);
+        }
+    }
+
+    return(FALSE);
+}
+
+static void toggle_visible_cb(GtkStatusIcon *status_icon, gpointer user_data)
+{
+    orage_toggle_visible();
+}
+
+static void show_menu(GtkStatusIcon *status_icon, guint button, guint activate_time
         , gpointer user_data)
 {
     gtk_menu_popup((GtkMenu *)user_data, NULL, NULL, NULL, NULL
             , button, activate_time);
 }
 
-void create_icon_pango_layout(gint line, PangoLayout *pl, struct tm *t
+static void create_icon_pango_layout(gint line, PangoLayout *pl, struct tm *t
         , gint width, gint height
         , gint *x_offset, gint *y_offset, gint *y_size)
 {
@@ -342,64 +389,64 @@ GdkPixbuf *orage_create_icon(gboolean static_icon, gint size)
     return(pixbuf);
 }
 
-GtkWidget *create_TrayIcon_menu()
+static GtkWidget *create_TrayIcon_menu(void)
 {
     CalWin *xfcal = (CalWin *)g_par.xfcal;
     GtkWidget *trayMenu;
     GtkWidget *menuItem;
 
     trayMenu = gtk_menu_new();
+
     menuItem = gtk_image_menu_item_new_with_mnemonic(_("Today"));
     gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem)
             , gtk_image_new_from_stock(GTK_STOCK_HOME, GTK_ICON_SIZE_MENU));
-    g_signal_connect(menuItem, "activate", G_CALLBACK(on_Today_activate)
-            , xfcal);
+    g_signal_connect(menuItem, "activate"
+            , G_CALLBACK(on_Today_activate), xfcal);
     gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
-    gtk_widget_show_all(menuItem);
+
     menuItem = gtk_separator_menu_item_new();
     gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
-    gtk_widget_show(menuItem);
-
     menuItem = gtk_image_menu_item_new_with_label(_("New appointment"));
     gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem)
             , gtk_image_new_from_stock(GTK_STOCK_NEW, GTK_ICON_SIZE_MENU));
     g_signal_connect(menuItem, "activate"
             , G_CALLBACK(on_new_appointment_activate), NULL);
     gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
-    gtk_widget_show(menuItem);
-    menuItem = gtk_separator_menu_item_new();
-    gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
-    gtk_widget_show(menuItem);
   
-    menuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_PREFERENCES, NULL);
-    g_signal_connect(menuItem, "activate", G_CALLBACK(on_preferences_activate)
-            , NULL);
-    gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
-    gtk_widget_show(menuItem);
     menuItem = gtk_separator_menu_item_new();
     gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
-    gtk_widget_show(menuItem);
+    menuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_PREFERENCES, NULL);
+    g_signal_connect(menuItem, "activate"
+            , G_CALLBACK(on_preferences_activate), NULL);
+    gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
 
+    menuItem = gtk_separator_menu_item_new();
+    gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
     menuItem = gtk_image_menu_item_new_with_label(_("About Orage"));
     gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem)
             , gtk_image_new_from_stock(GTK_STOCK_ABOUT, GTK_ICON_SIZE_MENU));
-    g_signal_connect(menuItem, "activate", G_CALLBACK(on_about_activate)
-            , xfcal);
+    g_signal_connect(menuItem, "activate"
+            , G_CALLBACK(on_about_activate), xfcal);
     gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
-    gtk_widget_show(menuItem);
+
     menuItem = gtk_separator_menu_item_new();
     gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
-    gtk_widget_show(menuItem);
-
     menuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_QUIT, NULL);
     g_signal_connect(menuItem, "activate", G_CALLBACK(gtk_main_quit), NULL);
     gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
-    gtk_widget_show(menuItem);
+  
+    menuItem = gtk_separator_menu_item_new();
+    gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
+    menuItem = gtk_image_menu_item_new_with_label(_("Globaltime"));
+    g_signal_connect(menuItem, "activate"
+            , G_CALLBACK(on_globaltime_activate), NULL);
+    gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
 
+    gtk_widget_show_all(trayMenu);
     return(trayMenu);
 }
 
-void destroy_TrayIcon(GtkStatusIcon *trayIcon)
+static void destroy_TrayIcon(GtkStatusIcon *trayIcon)
 {
     g_object_unref(trayIcon);
 }
@@ -422,6 +469,8 @@ GtkStatusIcon* create_TrayIcon(GdkPixbuf *orage_logo)
     g_object_ref(trayIcon);
     g_object_ref_sink(trayIcon);
 
+    g_signal_connect(G_OBJECT(trayIcon), "button-press-event",
+    			   G_CALLBACK(button_press_cb), xfcal);
     g_signal_connect(G_OBJECT(trayIcon), "activate",
     			   G_CALLBACK(toggle_visible_cb), xfcal);
     g_signal_connect(G_OBJECT(trayIcon), "popup_menu",
@@ -429,7 +478,7 @@ GtkStatusIcon* create_TrayIcon(GdkPixbuf *orage_logo)
     return(trayIcon);
 }
 
-void refresh_TrayIcon()
+void refresh_TrayIcon(void)
 {
     GdkPixbuf *orage_logo;
 
