@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2008 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2008-2011 Juha Kautto  (juha at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -141,14 +141,14 @@ void read_file(const char *file_name, const struct stat *file_stat)
         printf("read_file: end\n");
 }
 
-long get_long()
+int get_long()
 {
-    unsigned long tmp;
+    int tmp;
 
-    tmp = (((long)in_head[0]<<24)
-         + ((long)in_head[1]<<16)
-         + ((long)in_head[2]<<8)
-         +  (long)in_head[3]);
+    tmp = (((int)in_head[0]<<24)
+         + ((int)in_head[1]<<16)
+         + ((int)in_head[2]<<8)
+         +  (int)in_head[3]);
     in_head += 4;
     return(tmp);
 }
@@ -187,7 +187,7 @@ int process_header()
 
 void process_local_time_table()
 { /* points when time changes */
-    unsigned long tmp;
+    time_t tmp;
     int i;
 
     begin_timechanges = in_head;
@@ -196,9 +196,9 @@ void process_local_time_table()
     for (i = 0; i < timecnt; i++) {
         tmp = get_long();
         if (debug > 3) {
-            printf("GMT %d: %lu =  %s", i, tmp
+            printf("GMT %d: %d =  %s", i, (int)tmp
                     , asctime(gmtime((const time_t*)&tmp)));
-            printf("\tLOC %d: %lu =  %s", i, tmp
+            printf("\tLOC %d: %d =  %s", i, (int)tmp
                     , asctime(localtime((const time_t*)&tmp)));
         }
     }
@@ -252,7 +252,8 @@ void process_abbr_table()
     tmp = in_head;
     for (i = 0; i < charcnt; i++) { /* we need to walk over the table */
         if (debug > 3)
-            printf("Abbr:%d (%d)(%s)\n", i, strlen((char *)(tmp + i)), tmp + i);
+            printf("Abbr:%d (%d)(%s)\n", i, (int)strlen((char *)(tmp + i))
+                    , tmp + i);
         i += strlen((char *)(tmp + i));
     }
     in_head += charcnt;
